Learn R Programming

eRm (version 0.15-3)

item_info: Calculate Item Information for 'eRm' objects

Description

Calculates Samejima's (1969) information for all items

Usage

item_info(ermobject, theta = seq(-5, 5, 0.01))

i_info(hvec, itembeta, theta)

Arguments

ermobject
An object of class 'eRm'.
theta
Supporting or sampling points on the latent trait.
hvec
Number of categories of a single item.
itembeta
Cumulative item category parameters for a single item.

Value

  • Returns a list (i_info) or a list of lists (where each element corresponds to an item, item_info) and contains
  • c.infoMatrix of category information in columns for the different theta values in rows.
  • i.infoVector of item information for the different theta values.

Details

The function item_info calculates information of the whole set of items in the 'eRm' object. The function i_info does the same for a single item (and is called by item_info).

References

Samejima, F. (1969) Estimation of latent ability using a response pattern of graded scores. Psychometric Monographs, 17.

See Also

The function to calculate the test information, test_info and the plot function plotINFO.

Examples

Run this code
res <- PCM(pcmdat)
info <- item_info(res)
plotINFO(res,type="item")

Run the code above in your browser using DataLab