eRm.## S3 method for class 'eRm':
print(x, ...)
## S3 method for class 'eRm':
summary(object, ...)
## S3 method for class 'eRm':
coef(object, parm="beta", ...)
## S3 method for class 'eRm':
model.matrix(object, ...)
## S3 method for class 'eRm':
vcov(object, ...)
## S3 method for class 'eRm':
logLik(object, ...)
## S3 method for class 'eRm':
confint(object, parm = "beta", level = 0.95, ...)eRm.eRm."eta" or "beta".vcov returns the variance-covariance matrix of the parameter estimates,
coef a vector of estimates of the eta or beta basic parameters,
model.matrix the design matrix,
logLik an object with elements loglik and df containing
the log-likelihood value and df.
confint a matrix of confidence interval values for eta or beta.print method displays the value of
the log-likelihood, parameter estimates (basic parameters eta) and their standard errors.
For RM, RSM, and PCM models, the etas are difficulty parameters, for the LLTM, LRSM,
LPCM the sign of the parameters depend on the design matrix and are easiness effects by default.
The summary method additionally gives the full set of item parameters beta as
easiness parameters for all models.
Print methods are also available for the functions logLik and confint
(see below).res <- RM(raschdat1)
res
summary(res)
coef(res)
vcov(res)
model.matrix(res)
logLik(res)Run the code above in your browser using DataLab