Learn R Programming

eRm (version 0.15-3)

summary.llra: Summarizing Linear Logistic Models with Relaxed Assumptions (LLRA)

Description

summary method for class "llra"

Usage

## S3 method for class 'llra':
summary(object, level, ...)

## S3 method for class 'summary.llra':
print(x, ...)

Arguments

object
an object of class "llra", typically result of a call to LLRA.
x
an object of class "summary.llra", usually, a result of a call to summary.llra.
level
The level of confidence for the confidence intervals. Default is 0.95.
...
further arguments passed to or from other methods.

Value

  • The function summary.lllra computes and returns a list of summary statistics of the fitted LLRA given in object, reusing the components (list elements) call, etapar, iter, loglik, model, npar and se.etapar from its argument, plus
  • ciThe upper and lower confidence interval borders.

Details

Objects of class "summary.llra" contain all parameters of interest plus the confidence intervals. print.summary.llra rounds the values to 3 digits and displays them nicely.

See Also

The model fitting function LLRA.

Examples

Run this code
##Example 6 from Hatzinger & Rusch (2009)
groups <- c(rep("TG",30),rep("CG",30))
llra1 <- LLRA(llradat3,mpoints=2,groups=groups)
summary(llra1)

##An LLRA with 2 treatment groups and 1 baseline group, 5 items and 4
##time points. Item 1 is dichotomous, all others have 3, 4, 5, 6
##categories respectively.
ex2 <- LLRA(llraDat2[1:20],mpoints=4,llraDat2[21])
sumEx2 <- summary(ex2, level=0.95)

#print a summary
sumEx2

#get confidence intervals
sumEx2$ci

Run the code above in your browser using DataLab